ProSHADE: Class Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - f -

- figureIndexStartStop() : ProSHADE_internal_data::ProSHADE_data
- fileName : ProSHADE_internal_data::ProSHADE_data
- fileType : ProSHADE_internal_data::ProSHADE_data
- findAllPeaks() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- findBestCScore() : ProSHADE_internal_data::ProSHADE_data
- findBestDScore() : ProSHADE_internal_data::ProSHADE_data
- findCyclicPointGroupsGivenFold() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- findIScore() : ProSHADE_internal_data::ProSHADE_data
- findMapCOM() : ProSHADE_internal_data::ProSHADE_data
- findOScore() : ProSHADE_internal_data::ProSHADE_data
- findRequestedCSymmetryFromAngleAxis() : ProSHADE_internal_data::ProSHADE_data
- findTScore() : ProSHADE_internal_data::ProSHADE_data
- firstModelOnly : ProSHADE_settings
- forceBounds : ProSHADE_settings
- forceP1 : ProSHADE_settings